@@ -3,7 +3,7 @@ import logging
 from typing import Optional, List, Dict, Any, Tuple, Set, cast
 from collections import namedtuple
 from os import environ
-from time import monotonic as time
+from time import perf_counter as time
 
 from jinja2 import Template, Environment
 from jinja2.meta import find_undeclared_variables
@@ -86,14 +86,16 @@ def transform(data: Dict[str, Any], objectify: Optional[bool] = True) -> Dict[st
                 try:
                     value = variable_instance[variable_name]
                 except Exception as e:
+                    import traceback
+                    traceback.print_exc()
                     exception = e
                     logger.error(str(e), exc_info=grizzly.state.verbose)
                 finally:
-                    total_time = int((time() - start_time) * 1000)
+                    response_time = int((time() - start_time) * 1000)
                     grizzly.state.environment.events.request.fire(
                         request_type='VAR ',
                         name=key,
-                        response_time=total_time,
+                        response_time=response_time,
                         response_length=0,
                         context=None,
                         exception=exception,
